package com.sun.jmx.snmp.IPAcl;

import java.util.Vector;
import java.util.Enumeration;
import java.net.InetAddress;
import java.security.Principal;
import java.util.logging.Level;
import com.sun.jmx.defaults.JmxProperties;
import java.net.UnknownHostException;
import java.io.Serializable;
import java.security.acl.Group;

class NetMaskImpl extends PrincipalImpl implements Group, Serializable
{
    private static final long serialVersionUID = -7332541893877932896L;
    protected byte[] subnet;
    protected int prefix;
    
    public NetMaskImpl() throws UnknownHostException {
        this.subnet = null;
        this.prefix = -1;
    }
    
    private byte[] extractSubNet(byte[] array) {
        int length = array.length;
        if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
            JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "BINARY ARRAY :");
            StringBuffer sb = new StringBuffer();
            for (int i = 0; i < length; ++i) {
                sb.append((array[i] & 0xFF) + ":");
            }
            JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", sb.toString());
        }
        int n = this.prefix / 8;
        if (n == length) {
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "The mask is the complete address, strange..." + length);
            }
            return array;
        }
        else if (n > length) {
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "The number of covered byte is longer than the address. BUG");
            }
            throw new IllegalArgumentException("The number of covered byte is longer than the address.");
        }
        else {
            int j = n;
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "Partially covered index : " + j);
            }
            int k = array[j];
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "Partially covered byte : " + k);
            }
            int l = this.prefix % 8;
            if (l == 0) {
            }
            else {
                ++j;
            }
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "Remains : " + l);
            }
            int n2 = 0;
            for (int n3 = 0; n3 < l; ++n3) {
                n2 = (byte)(n2 | 1 << 7 - n3);
            }
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "Mask value : " + (n2 & 0xFF));
            }
            int n4 = (byte)(k & n2);
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "Masked byte : " + (n4 & 0xFF));
            }
            byte[] array2 = new byte[j];
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "Resulting subnet : ");
            }
            for (int n5 = 0; n5 < j; ++n5) {
                array2[n5] = array[n5];
                if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                    JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", (array2[n5] & 0xFF) + ":");
                }
            }
            if (l != 0) {
                array2[j] = n4;
                if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                    JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "extractSubNet", "Last subnet byte : " + (array2[j] & 0xFF));
                }
            }
            return array2;
        }
    }
    
    public NetMaskImpl(String s, int prefix) throws UnknownHostException {
        super(s);
        this.subnet = null;
        this.prefix = -1;
        this.prefix = prefix;
        this.subnet = this.extractSubNet(this.getAddress().getAddress());
    }
    
    public boolean addMember(Principal principal) {
        return true;
    }
    
    @Override
    public int hashCode() {
        return super.hashCode();
    }
    
    @Override
    public boolean equals(Object o) {
        if (o instanceof PrincipalImpl || o instanceof NetMaskImpl) {
            InetAddress address = ((PrincipalImpl)o).getAddress();
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "equals", "Received Address : " + address);
            }
            byte[] address2 = address.getAddress();
            int i = 0;
            while (i < this.subnet.length) {
                if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                    JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "equals", "(recAddr[i]) : " + (address2[i] & 0xFF));
                    JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "equals", "(recAddr[i] & subnet[i]) : " + (address2[i] & this.subnet[i] & 0xFF) + " subnet[i] : " + (this.subnet[i] & 0xFF));
                }
                if ((address2[i] & this.subnet[i]) != this.subnet[i]) {
                    if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                        JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "equals", "FALSE");
                    }
                    return false;
                }
                else {
                    ++i;
                }
            }
            if (JmxProperties.SNMP_LOGGER.isLoggable(Level.FINEST)) {
                JmxProperties.SNMP_LOGGER.logp(Level.FINEST, NetMaskImpl.class.getName(), "equals", "TRUE");
            }
            return true;
        }
        else {
            return false;
        }
    }
    
    public boolean isMember(Principal principal) {
        return (principal.hashCode() & super.hashCode()) == principal.hashCode();
    }
    
    public Enumeration<? extends Principal> members() {
        Vector vector = new Vector(1);
        vector.addElement(this);
        return vector.elements();
    }
    
    public boolean removeMember(Principal principal) {
        return true;
    }
    
    @Override
    public String toString() {
        return "NetMaskImpl :" + super.getAddress().toString() + "/" + this.prefix;
    }
}
